# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import enum

import winrt.system
from winrt import _winrt_windows_ui_viewmanagement_core

__all__ = [
    "CoreInputViewKind",
    "CoreInputViewOcclusionKind",
    "CoreInputViewXYFocusTransferDirection",
    "CoreFrameworkInputView",
    "CoreFrameworkInputViewAnimationStartingEventArgs",
    "CoreFrameworkInputViewOcclusionsChangedEventArgs",
    "CoreInputView",
    "CoreInputViewAnimationStartingEventArgs",
    "CoreInputViewHidingEventArgs",
    "CoreInputViewOcclusion",
    "CoreInputViewOcclusionsChangedEventArgs",
    "CoreInputViewShowingEventArgs",
    "CoreInputViewTransferringXYFocusEventArgs",
    "UISettingsController",
]

class CoreInputViewKind(enum.IntEnum):
    DEFAULT = 0
    KEYBOARD = 1
    HANDWRITING = 2
    EMOJI = 3
    SYMBOLS = 4
    CLIPBOARD = 5
    DICTATION = 6

class CoreInputViewOcclusionKind(enum.IntEnum):
    DOCKED = 0
    FLOATING = 1
    OVERLAY = 2

class CoreInputViewXYFocusTransferDirection(enum.IntEnum):
    UP = 0
    RIGHT = 1
    DOWN = 2
    LEFT = 3

CoreFrameworkInputView = _winrt_windows_ui_viewmanagement_core.CoreFrameworkInputView
CoreFrameworkInputViewAnimationStartingEventArgs = _winrt_windows_ui_viewmanagement_core.CoreFrameworkInputViewAnimationStartingEventArgs
CoreFrameworkInputViewOcclusionsChangedEventArgs = _winrt_windows_ui_viewmanagement_core.CoreFrameworkInputViewOcclusionsChangedEventArgs
CoreInputView = _winrt_windows_ui_viewmanagement_core.CoreInputView
CoreInputViewAnimationStartingEventArgs = _winrt_windows_ui_viewmanagement_core.CoreInputViewAnimationStartingEventArgs
CoreInputViewHidingEventArgs = _winrt_windows_ui_viewmanagement_core.CoreInputViewHidingEventArgs
CoreInputViewOcclusion = _winrt_windows_ui_viewmanagement_core.CoreInputViewOcclusion
CoreInputViewOcclusionsChangedEventArgs = _winrt_windows_ui_viewmanagement_core.CoreInputViewOcclusionsChangedEventArgs
CoreInputViewShowingEventArgs = _winrt_windows_ui_viewmanagement_core.CoreInputViewShowingEventArgs
CoreInputViewTransferringXYFocusEventArgs = _winrt_windows_ui_viewmanagement_core.CoreInputViewTransferringXYFocusEventArgs
UISettingsController = _winrt_windows_ui_viewmanagement_core.UISettingsController
